@@ -3,6 +3,7 @@ from typing import Optional
 
 from MLMetaRequest import ModelMetaRequest
 from MLPredictRequest import ModelPredictRequest
+from MLLivePredictRequest import ModelLivePredictRequest
 from MLTrainRequest import ModelTrainRequest
 from MLEvalRequest import ModelEvaluateRequest
 
@@ -10,6 +11,7 @@ from MLEvalRequest import ModelEvaluateRequest
 class MLGatewayRequest(BaseModel):
     meta: Optional[ModelMetaRequest]
     predict: Optional[ModelPredictRequest]
+    live_predict: Optional[ModelLivePredictRequest]
     train: Optional[ModelTrainRequest]
     evaluate: Optional[ModelEvaluateRequest]
 
